<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
  <context>
    <name>CmdApproxCylinder</name>
    <message>
      <location filename="../../Command.cpp" line="205"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="206"/>
      <source>Cylinder</source>
      <translation>Zylinder</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="207"/>
      <source>Approximate a cylinder</source>
      <translation>Einen Zylinder annähern</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Plane...</source>
      <translation>Ebene...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Approximate a plane</source>
      <translation>Approximieren einer Ebene</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPolynomial</name>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="319"/>
      <source>Polynomial surface</source>
      <translation>Polynomfläche</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Approximate a polynomial surface</source>
      <translation>Eine Polynomfläche annähern</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSphere</name>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="272"/>
      <source>Sphere</source>
      <translation>Kugel</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="273"/>
      <source>Approximate a sphere</source>
      <translation>Eine Kugel annähern</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <source>Approximate B-spline surface...</source>
      <translation>B-Spline-Fläche approximieren...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <source>Approximate a B-spline surface</source>
      <translation>Approximiere eine B-Spline-Fläche</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshBoundary</name>
    <message>
      <location filename="../../Command.cpp" line="484"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="485"/>
      <source>Wire from mesh boundary...</source>
      <translation>Draht von Netzgrenze...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="486"/>
      <source>Create wire from mesh boundaries</source>
      <translation>Erstelle Kantenzug aus Netzbegrenzungen</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location filename="../../Command.cpp" line="550"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="551"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="552"/>
      <source>Poisson surface reconstruction</source>
      <translation>Poisson-Oberflächenrekonstruktion</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentation</name>
    <message>
      <location filename="../../Command.cpp" line="373"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="374"/>
      <source>Mesh segmentation...</source>
      <translation>Netz-Segmentierung...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>Create mesh segments</source>
      <translation>Netz-Segmente erstellen</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationFromComponents</name>
    <message>
      <location filename="../../Command.cpp" line="434"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="435"/>
      <source>From components</source>
      <translation>Aus Komponenten</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="436"/>
      <source>Create mesh segments from components</source>
      <translation>Erstelle Netzsegmente aus Komponenten</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationManual</name>
    <message>
      <location filename="../../Command.cpp" line="405"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="406"/>
      <source>Manual segmentation...</source>
      <translation>Manuelle Segmentierung...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Create mesh segments manually</source>
      <translation>Netzsegmente manuell erstellen</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="584"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="585"/>
      <source>Structured point clouds</source>
      <translation>Geordnete Punktwolken</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="586"/>
      <location filename="../../Command.cpp" line="587"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulation von geordneten Punktwolken</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="184"/>
      <source>Fit plane</source>
      <translation>Ebene einpassen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="215"/>
      <source>Fit cylinder</source>
      <translation>Zylinder einpassen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="281"/>
      <source>Fit sphere</source>
      <translation>Kugel einpassen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="329"/>
      <source>Fit polynomial surface</source>
      <translation>Polynomfläche einpassen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="595"/>
      <source>View triangulation</source>
      <translation>Triangulation anzeigen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="150"/>
      <source>Placement</source>
      <translation>Positionierung</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="222"/>
      <source>Fit B-Spline</source>
      <translation>B-Spline einpassen</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="91"/>
      <source>Poisson reconstruction</source>
      <translation>Poisson-Rekonstruktion</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.cpp" line="257"/>
      <source>Segmentation</source>
      <translation>Segmentierung</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>B-Spline-Fläche annähern</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="20"/>
      <source>u-Direction</source>
      <translation>u-Richtung</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="26"/>
      <location filename="../../FitBSplineSurface.ui" line="93"/>
      <source>Degree</source>
      <translation>Grad</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="55"/>
      <location filename="../../FitBSplineSurface.ui" line="122"/>
      <source>Control points</source>
      <translation>Kontrollpunkte</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="87"/>
      <source>v-Direction</source>
      <translation>v-Richtung</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="154"/>
      <source>Settings</source>
      <translation>Einstellungen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="160"/>
      <source>Iterations</source>
      <translation>Iterationen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="189"/>
      <source>Size factor</source>
      <translation>Größen-Faktor</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="218"/>
      <source>User-defined u/v directions</source>
      <translation>Nutzer-definierte u/v-Richtungen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="231"/>
      <source>Create placement</source>
      <translation>Placement erstellen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="238"/>
      <source>Smoothing</source>
      <translation>Glättung</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="247"/>
      <source>Total Weight</source>
      <translation>Gesamtgewicht</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="276"/>
      <source>Length of gradient</source>
      <translation>Länge des Gradienten</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="305"/>
      <source>Bending energy</source>
      <translation>Biegeenergie</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="334"/>
      <source>Curvature variation</source>
      <translation>Variation der Krümmung</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="161"/>
      <location filename="../../FitBSplineSurface.cpp" line="229"/>
      <source>Input error</source>
      <translation>Eingabefehler</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="201"/>
      <source>Wrong selection</source>
      <translation>Falsche Auswahl</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="202"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Bitte ein einzelnes Placement-Objekt zur lokalen Orientierung wählen.</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="20"/>
      <source>Parameters</source>
      <translation>Parameter</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="26"/>
      <source>Octree depth</source>
      <translation>Octree-Tiefe</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="46"/>
      <source>Solver divide</source>
      <translation>Solver - Aufteilung</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="66"/>
      <source>Samples per node</source>
      <translation>Samples pro Knoten</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="98"/>
      <source>Input error</source>
      <translation>Eingabefehler</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <location filename="../../Command.cpp" line="563"/>
      <source>Wrong selection</source>
      <translation>Falsche Auswahl</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Please select a point cloud or mesh.</source>
      <translation>Bitte wählen Sie eine Punktwolke oder ein Netz.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="564"/>
      <source>Please select a single point cloud.</source>
      <translation>Bitte eine einzelne Punktewolke auswählen.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="617"/>
      <source>View triangulation failed</source>
      <translation>Ansichts-Triangulation fehlgeschlagen</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::Segmentation</name>
    <message>
      <location filename="../../Segmentation.ui" line="14"/>
      <source>Mesh segmentation</source>
      <translation>Netz-Segmentierung</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="20"/>
      <source>Smooth mesh</source>
      <translation>Netz glätten</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="37"/>
      <source>Plane</source>
      <translation>Ebene</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="46"/>
      <source>Curvature tolerance</source>
      <translation>Krümmungstoleranz</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="63"/>
      <source>Distance to plane</source>
      <translation>Entfernung zur Ebene</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="80"/>
      <source>Minimum number of faces</source>
      <translation>Minimale Anzahl von Dreiecken</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="100"/>
      <source>Create mesh from unused triangles</source>
      <translation>Erstelle Netz aus ungenutzten Dreiecken</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="107"/>
      <source>Create compound</source>
      <translation>Verbund erstellen</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::SegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.ui" line="14"/>
      <source>Manual segmentation</source>
      <translation>Manuelle Segmentierung</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="20"/>
      <source>Select</source>
      <translation>Wähle</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="41"/>
      <source>Region</source>
      <translation>Bereich</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="61"/>
      <source>All</source>
      <translation>Alles</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="81"/>
      <source>Components</source>
      <translation>Komponenten</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="88"/>
      <source>&lt; faces than</source>
      <translation>&lt; Dreiecke als</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="98"/>
      <source>Pick triangle</source>
      <translation>Dreieck aufnehmen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="105"/>
      <source>Select whole component</source>
      <translation>Ganze Komponente auswählen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="112"/>
      <source>Clear</source>
      <translation>Löschen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="122"/>
      <source>Plane</source>
      <translation>Ebene</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="128"/>
      <location filename="../../SegmentationManual.ui" line="181"/>
      <location filename="../../SegmentationManual.ui" line="234"/>
      <source>Detect</source>
      <translation>Erkennen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="135"/>
      <location filename="../../SegmentationManual.ui" line="188"/>
      <location filename="../../SegmentationManual.ui" line="241"/>
      <source>Tolerance</source>
      <translation>Toleranz</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="155"/>
      <location filename="../../SegmentationManual.ui" line="208"/>
      <location filename="../../SegmentationManual.ui" line="261"/>
      <source>Minimum number of faces</source>
      <translation>Minimale Anzahl von Dreiecken</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="175"/>
      <source>Cylinder</source>
      <translation>Zylinder</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="228"/>
      <source>Sphere</source>
      <translation>Kugel</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="281"/>
      <source>Region options</source>
      <translation>Einstellungen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="287"/>
      <source>Respect only visible triangles</source>
      <translation>Nur sichtbare Dreiecke berücksichtigen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="297"/>
      <source>Respect only triangles with normals facing screen</source>
      <translation>Nur Dreiecke mit Normalen beachten, die zum Bildschirm zeigen</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="310"/>
      <source>Segmentation</source>
      <translation>Segmentierung</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="316"/>
      <source>Cut segment from mesh</source>
      <translation>Segment aus Netz schneiden</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="326"/>
      <source>Hide segment</source>
      <translation>Segment ausblenden</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::TaskSegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.cpp" line="333"/>
      <source>Create</source>
      <translation>Erstellen</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Reverse Engineering</source>
      <translation>Rückführung</translation>
    </message>
  </context>
</TS>
